@@ -60,17 +60,12 @@
 #include <linux/videodev.h>
 #include <linux/videodev2.h>
 #include <linux/i2c.h>
-#include <media/v4l2-common.h>
+#include <media/v4l2-i2c-drv.h>
 
 MODULE_DESCRIPTION("Philips SAA717x video decoder driver");
-MODULE_AUTHOR("Kevin Thayer, K. Ohta");
+MODULE_AUTHOR("K. Ohta");
 MODULE_LICENSE("GPL");
 
-#ifdef VIDIOC_DBG_S_REGISTER
-#define VIDIOC_INT_S_REGISTER VIDIOC_DBG_S_REGISTER
-#define VIDIOC_INT_G_REGISTER VIDIOC_DBG_G_REGISTER
-#endif
-
 static int debug = 0;
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 0)
 module_param(debug, int, 0644);
@@ -79,6 +74,19 @@ MODULE_PARM(debug, "i");
 #endif
 MODULE_PARM_DESC(debug, "Debug level (0-1)");
 
+/*
+ * Generic i2c probe
+ * concerning the addresses: i2c wants 7 bit (without the r/w bit), so '>>1'
+ */
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,22)
+static unsigned short normal_i2c[] = { 0x42 >> 1, I2C_CLIENT_END };
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13)
+static unsigned short normal_i2c_range[] = { I2C_CLIENT_END };
+#endif
+
+I2C_CLIENT_INSMOD;
+#endif
+
 struct saa717x_state {
 	v4l2_std_id std;
 	int input;
@@ -1258,31 +1266,25 @@ static int saa717x_command(struct i2c_client *client, unsigned int cmd, void *ar
 	}
 
 #ifdef CONFIG_VIDEO_ADV_DEBUG
-	case VIDIOC_INT_G_REGISTER:
+	case VIDIOC_DBG_G_REGISTER:
 	{
 		struct v4l2_register *reg = arg;
 
-#if LINUX_VERSION_CODE <= KERNEL_VERSION(2,6,20)
-		if (reg->i2c_id != I2C_DRIVERID_SAA717X)
-#else
 		if (!v4l2_chip_match_i2c_client(client, reg->match_type, reg->match_chip))
-#endif
 			return -EINVAL;
+		if (!capable(CAP_SYS_ADMIN))
+			return -EPERM;
 		reg->val = saa717x_read(client, reg->reg);
 		break;
 	}
 
-	case VIDIOC_INT_S_REGISTER:
+	case VIDIOC_DBG_S_REGISTER:
 	{
 		struct v4l2_register *reg = arg;
 		u16 addr = reg->reg & 0xffff;
 		u8 val = reg->val & 0xff;
 
-#if LINUX_VERSION_CODE <= KERNEL_VERSION(2,6,20)
-		if (reg->i2c_id != I2C_DRIVERID_SAA717X)
-#else
 		if (!v4l2_chip_match_i2c_client(client, reg->match_type, reg->match_chip))
-#endif
 			return -EINVAL;
 		if (!capable(CAP_SYS_ADMIN))
 			return -EPERM;
@@ -1504,46 +1506,17 @@ static int saa717x_command(struct i2c_client *client, unsigned int cmd, void *ar
 
 /* i2c implementation */
 
-/*
- * Generic i2c probe
- * concerning the addresses: i2c wants 7 bit (without the r/w bit), so '>>1'
- */
-static unsigned short normal_i2c[] = { 0x42 >> 1, 0x42 >> 1, I2C_CLIENT_END };
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13)
-static unsigned short normal_i2c_range[] = { I2C_CLIENT_END };
-#endif	/* LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13) */
-
-I2C_CLIENT_INSMOD;
-
-struct i2c_driver i2c_driver;
-
-
 /* ----------------------------------------------------------------------- */
-static int saa717x_detect_client (struct i2c_adapter *adapter,
-		       int                 address,
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0)
-		       unsigned short flags, 
-#endif
-		       int                 kind)
+static int saa717x_probe(struct i2c_client *client)
 {
-	struct i2c_client *client;
 	struct saa717x_state *decoder;
 	u8 id = 0;
 	char *p = "";
 
 	/* Check if the adapter supports the needed features */
-	if (!i2c_check_functionality(adapter, I2C_FUNC_SMBUS_BYTE_DATA))
-		return 0;
+	if (!i2c_check_functionality(client->adapter, I2C_FUNC_SMBUS_BYTE_DATA))
+		return -EIO;
 
-	client = kzalloc(sizeof(struct i2c_client), GFP_KERNEL);
-	if (client == 0)
-		return -ENOMEM;
-	client->addr = address;
-	client->adapter = adapter;
-	client->driver = &i2c_driver;
-#if LINUX_VERSION_CODE <= KERNEL_VERSION(2,6,15)
-	client->flags = I2C_CLIENT_ALLOW_USE;
-#endif
 	snprintf(client->name, sizeof(client->name) - 1, "saa717x");
 
 	if (saa717x_write(client, 0x5a4, 0xfe) &&
@@ -1554,20 +1527,18 @@ static int saa717x_detect_client (struct i2c_adapter *adapter,
 	}
 	if (id != 0xc2 && id != 0x32 && id != 0xf2 && id != 0x6c) {
 		v4l_dbg(1, debug, client, "saa717x not found (id=%02x)\n", id);
-		kfree(client);
-		return 0;
+		return -ENODEV;
 	}
 	if (id == 0xc2) p = "saa7173";
 	else if (id == 0x32) p = "saa7174A";
 	else if (id == 0x6c) p = "saa7174HL";
 	else p = "saa7171";
-	v4l_info(client, "%s found @ 0x%x (%s)\n", p, address << 1, adapter->name);
+	v4l_info(client, "%s found @ 0x%x (%s)\n", p, client->addr << 1, client->adapter->name);
 
 	decoder = kzalloc(sizeof(struct saa717x_state), GFP_KERNEL);
 	i2c_set_clientdata(client, decoder); 
 
 	if (decoder == NULL) {
-		kfree(client);
 		return -ENOMEM;
 	}
 	decoder->std = V4L2_STD_NTSC;
@@ -1609,80 +1580,28 @@ static int saa717x_detect_client (struct i2c_adapter *adapter,
 
 	set_current_state(TASK_INTERRUPTIBLE);
 	schedule_timeout(2*HZ);
-	
-	i2c_attach_client(client);
-
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0)
-	MOD_INC_USE_COUNT;
-#endif
 	return 0;
 }
 
-static int
-saa717x_attach_adapter (struct i2c_adapter *adapter)
+static int saa717x_remove(struct i2c_client *client)
 {
-#ifdef I2C_CLASS_TV_ANALOG
-	if (adapter->class & I2C_CLASS_TV_ANALOG)
-#else
-	if (adapter->id == I2C_HW_B_BT848)
-#endif
-		return i2c_probe(adapter, &addr_data, &saa717x_detect_client);
-	return 0;
-}
-
-static int
-saa717x_detach_client (struct i2c_client *client)
-{
-	struct saa717x *decoder = i2c_get_clientdata(client);
-	int err;
-
-	err = i2c_detach_client(client);
-	if (err) {
-		return err;
-	}
-
-	kfree(decoder);
-	kfree(client);
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0)
-	MOD_DEC_USE_COUNT;
-#endif
+	kfree(i2c_get_clientdata(client));
 	return 0;
 }
 
 /* ----------------------------------------------------------------------- */
 
-/* i2c implementation */
-struct i2c_driver i2c_driver = {
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0) && LINUX_VERSION_CODE <= KERNEL_VERSION(2,6,15)
-	.owner = THIS_MODULE,
-#endif
-#if LINUX_VERSION_CODE <= KERNEL_VERSION(2,6,15)
+static struct v4l2_i2c_driver_data v4l2_i2c_data = {
 	.name = "saa717x",
-	.flags = I2C_DF_NOTIFY,
-#else
-	.driver = {
-		.name = "saa717x",
-	},
-#endif
-	.id = I2C_DRIVERID_SAA717X,
-	.attach_adapter = saa717x_attach_adapter,
-	.detach_client = saa717x_detach_client,
+	.driverid = I2C_DRIVERID_SAA717X,
 	.command = saa717x_command,
+	.probe = saa717x_probe,
+	.remove = saa717x_remove,
+#ifdef I2C_CLASS_TV_ANALOG
+	.legacy_class = I2C_CLASS_TV_ANALOG | I2C_CLASS_TV_DIGITAL,
+#endif
 };
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0)
 EXPORT_NO_SYMBOLS;
 #endif
-
-static int __init saa717x_init_module(void)
-{
-	return i2c_add_driver(&i2c_driver);
-}
-
-static void __exit saa717x_exit_module(void)
-{
-	i2c_del_driver(&i2c_driver);
-}
-
-module_init(saa717x_init_module);
-module_exit(saa717x_exit_module);
