@@ -33,10 +33,8 @@
 #include <sys/time.h>
 #include <math.h>
 #include <linux/types.h>
-
-#include "videodev2.h"
-
-#include "media/ivtv.h"
+#include <linux/videodev2.h>
+#include <linux/ivtv.h>
 
 #define I2C_DRIVERID_CX25840	71	/* cx2584x video encoder	*/
 #define I2C_DRIVERID_SAA711X	73	/* saa711x video encoders	*/
@@ -429,7 +427,7 @@ void decode_vps(struct v4l2_sliced_vbi_data *s)
 
 	pcs = buf[2] >> 6;
 
-	cni = +((buf[10] & 3) << 10)
+	cni = ((buf[2] & 0xf) << 12) + ((buf[10] & 3) << 10)
 	    + ((buf[11] & 0xC0) << 2)
 	    + ((buf[8] & 0xC0) << 0)
 	    + (buf[11] & 0x3F);
@@ -539,8 +537,12 @@ static void cc_readback(int fh)
 	v.match_type = V4L2_CHIP_MATCH_I2C_DRIVER;
 	v.match_chip = I2C_DRIVERID_CX25840;
 	v.reg = 0x444;
-	if (ioctl(fh, VIDIOC_DBG_G_REGISTER, &v))
+	if (ioctl(fh, VIDIOC_DBG_G_REGISTER, &v)) {
 		v.match_chip = I2C_DRIVERID_SAA711X;
+		printf("saa711x\n");
+	}
+	else
+		printf("cx25840\n");
 
 	while (1) {
 		if (v.match_chip == I2C_DRIVERID_CX25840) {
@@ -580,7 +582,7 @@ static void cc_readback(int fh)
 				continue;
 			}
 		}
-		struct timeval tv = { 0, 1000 };
+		struct timeval tv = { 0, 100 };
 		select(0, NULL, NULL, NULL, &tv);
 	}
 }
