@@ -52,20 +52,26 @@ int main(int argc, char *argv[])
 	int i, j;
 	
 	char *homedir = getenv("HOME");
-	char *config = (char*)malloc(strlen(homedir) + strlen("/.ivtv-tune") + 1);
-	sprintf(config, "%s/.ivtv-tune", homedir);
 
-	// create config file, if it doesn't already exist
-	if (stat(config, &buf) != 0)
+	if (homedir)
 	{
-		fp = fopen(config, "w");
-		fprintf(fp, "device /dev/video0\nfreqtable us-cable\n");
-		fclose(fp);
-	}
+		char *config = (char*)malloc(strlen(homedir) + strlen("/.ivtv-tune") + 1);
+		sprintf(config, "%s/.ivtv-tune", homedir);
 
-	cmdline_parser(argc, argv, &opt);
-	cmdline_parser_configfile(config, &opt, 0, 0, 0);
-	free(config);
+		// create config file, if it doesn't already exist
+		if (stat(config, &buf) != 0)
+		{
+			fp = fopen(config, "w");
+			fprintf(fp, "device /dev/video0\nfreqtable us-cable\n");
+			fclose(fp);
+		}
+
+		cmdline_parser(argc, argv, &opt);
+		cmdline_parser_configfile(config, &opt, 0, 0, 0);
+		free(config);
+	}
+	else
+		cmdline_parser(argc, argv, &opt);
 
 	if (opt.device_given)
 	{
@@ -191,6 +197,10 @@ int getfreqvalue(char *freqtable, char *channel)
 int getxawvalue(char *xawchannel)
 {
 	char *homedir = getenv("HOME");
+
+	if (!homedir)
+		return -1;
+
 	char *xawtv = (char*)malloc(strlen(homedir) + strlen("/.xawtv") + 1);
 	char *channel, *freqtable;
 
