@@ -37,20 +37,22 @@
 #include <linux/types.h>
 #include <sys/klog.h>
 
-#include "videodev2.h"
-#include "video.h"
+#include <linux/videodev2.h>
+#include <linux/dvb/video.h>
 
 /* copied from ivtv-driver.h */
-#define IVTV_DBGFLG_WARN  (1 << 0)
-#define IVTV_DBGFLG_INFO  (1 << 1)
-#define IVTV_DBGFLG_API   (1 << 2)
-#define IVTV_DBGFLG_DMA   (1 << 3)
-#define IVTV_DBGFLG_IOCTL (1 << 4)
-#define IVTV_DBGFLG_I2C   (1 << 5)
-#define IVTV_DBGFLG_IRQ   (1 << 6)
-#define IVTV_DBGFLG_DEC   (1 << 7)
-#define IVTV_DBGFLG_YUV   (1 << 8)
-#define IVTV_DBGFLG_HIGHVOL   (1 << 9)
+#define IVTV_DBGFLG_WARN    (1 << 0)
+#define IVTV_DBGFLG_INFO    (1 << 1)
+#define IVTV_DBGFLG_MB      (1 << 2)
+#define IVTV_DBGFLG_IOCTL   (1 << 3)
+#define IVTV_DBGFLG_FILE    (1 << 4)
+#define IVTV_DBGFLG_DMA     (1 << 5)
+#define IVTV_DBGFLG_IRQ     (1 << 6)
+#define IVTV_DBGFLG_DEC     (1 << 7)
+#define IVTV_DBGFLG_YUV     (1 << 8)
+#define IVTV_DBGFLG_I2C     (1 << 9)
+/* Flag to turn on high volume debugging */
+#define IVTV_DBGFLG_HIGHVOL (1 << 10)
 
 /* Internals copied from media/v4l2-common.h */
 struct v4l2_routing {
@@ -61,7 +63,7 @@ struct v4l2_routing {
 
 #define VIDIOC_INT_RESET            	_IOW ('d', 102, __u32)
 
-#include "media/ivtv.h"
+#include <linux/ivtv.h>
 
 #define __stringify_1(x)	#x
 #define __stringify(x)		__stringify_1(x)
@@ -78,24 +80,20 @@ enum Option {
 	OptSetDebugLevel = 'D',
 	OptSetDevice = 'd',
 	OptGetDebugLevel = 'e',
-	OptReloadFW = 'H',
 	OptHelp = 'h',
 	OptSetGPIO = 'i',
 	OptListGPIO = 'I',
 	OptPassThrough = 'K',
 	OptFrameSync = 'k',
 	OptSetAudioRoute = 'v',
-	OptLast = 128
+	OptReset = 128,
+	OptVersion,
+	OptSetYuvMode,
+	OptGetYuvMode,
+	OptLast = 256
 };
 
 static char options[OptLast];
-static int option_reset_ir = 0;
-static int option_version = 0;
-static int option_setYuvMode = 0;
-static int option_getYuvMode = 0;
-
-/* YUV mode specified */
-#define YUVMode 		(1L<<0)
 
 static struct option long_options[] = {
 	/* Please keep in alphabetical order of the short option.
@@ -103,17 +101,16 @@ static struct option long_options[] = {
 	{"set-debug", required_argument, 0, OptSetDebugLevel},
 	{"device", required_argument, 0, OptSetDevice},
 	{"get-debug", no_argument, 0, OptGetDebugLevel},
-	{"reload", no_argument, 0, OptReloadFW},
 	{"help", no_argument, 0, OptHelp},
 	{"set-gpio", required_argument, 0, OptSetGPIO},
 	{"list-gpio", no_argument, 0, OptListGPIO},
 	{"passthrough", required_argument, 0, OptPassThrough},
 	{"sync", no_argument, 0, OptFrameSync},
 	{"audio-route", required_argument, 0, OptSetAudioRoute},
-	{"reset-ir", no_argument, &option_reset_ir, 1},
-	{"version", no_argument, &option_version, 1},
-	{"get-yuv-mode", no_argument, &option_getYuvMode, 1},
-	{"set-yuv-mode", required_argument, &option_setYuvMode, 1},
+	{"reset", required_argument, 0, OptReset},
+	{"version", no_argument, 0, OptVersion},
+	{"get-yuv-mode", no_argument, 0, OptGetYuvMode},
+	{"set-yuv-mode", required_argument, 0, OptSetYuvMode},
 	{0, 0, 0, 0}
 };
 
@@ -131,16 +128,24 @@ static void usage(void)
 	printf("       		     mode 1: interlaced (bottom transmitted first)\n");
 	printf("       		     mode 2: progressive\n");
 	printf("       		     mode 3: auto\n");
-	printf("  --reset-ir         reset the infrared receiver [VIDIOC_INT_RESET]\n");
+	printf("  --reset <mask>     reset the infrared receiver (1) or digitizer (2) [VIDIOC_INT_RESET]\n");
 	printf("  --version          shows the version number of this utility.\n");
         printf("                     It should match the driver version.\n");
 	printf("\n");
 	printf("Expert options:\n");
 	printf("  -D, --set-debug <level>\n");
 	printf("                     set the module debug variable\n");
-	printf("                      1: WARN   2: INFO  4: API   8: DMA  16: IOCTL\n");
-	printf("                     32: I2C   64: IRQ 128: DEC 256: YUV 512: High Volume msgs\n");
-	printf("  -E, --end-gop      capture last GOP [IVTV_IOC_S_GOP_END]\n");
+	printf("                        1/0x0001: warning\n");
+	printf("                        2/0x0002: info\n");
+	printf("                        4/0x0004: mailbox\n");
+	printf("                        8/0x0008: ioctl\n");
+	printf("                       16/0x0010: file\n");
+	printf("                       32/0x0020: dma\n");
+	printf("                       64/0x0040: irq\n");
+	printf("                      128/0x0080: decoder\n");
+	printf("                      256/0x0100: yuv\n");
+	printf("                      512/0x0200: i2c\n");
+	printf("                     1024/0x0400: high volume\n");
 	printf("  -e, --get-debug    query the module debug variable\n");
 	printf("  -I, --list-gpio\n");
 	printf("                     show GPIO input/direction/output bits\n");
@@ -186,9 +191,9 @@ static void print_debug_mask(int mask)
 		mask &= ~IVTV_DBGFLG_INFO;
 		printf("IVTV_DBGFLG_INFO%s", MASK_OR_NOTHING);
 	}
-	if (mask & IVTV_DBGFLG_API) {
-		mask &= ~IVTV_DBGFLG_API;
-		printf("IVTV_DBGFLG_API%s", MASK_OR_NOTHING);
+	if (mask & IVTV_DBGFLG_MB) {
+		mask &= ~IVTV_DBGFLG_MB;
+		printf("IVTV_DBGFLG_MB%s", MASK_OR_NOTHING);
 	}
 	if (mask & IVTV_DBGFLG_DMA) {
 		mask &= ~IVTV_DBGFLG_DMA;
@@ -198,6 +203,10 @@ static void print_debug_mask(int mask)
 		mask &= ~IVTV_DBGFLG_IOCTL;
 		printf("IVTV_DBGFLG_IOCTL%s", MASK_OR_NOTHING);
 	}
+	if (mask & IVTV_DBGFLG_FILE) {
+		mask &= ~IVTV_DBGFLG_FILE;
+		printf("IVTV_DBGFLG_FILE%s", MASK_OR_NOTHING);
+	}
 	if (mask & IVTV_DBGFLG_I2C) {
 		mask &= ~IVTV_DBGFLG_I2C;
 		printf("IVTV_DBGFLG_I2C%s", MASK_OR_NOTHING);
@@ -316,7 +325,6 @@ int main(int argc, char **argv)
 	int fd = -1;
 
 	/* bitfield for OptSetCodec */
-	unsigned int set_yuvMode = 0;
 
 	/* command args */
 	char *device = strdup("/dev/video0");	/* -d device */
@@ -328,6 +336,7 @@ int main(int argc, char **argv)
 	int gpio_set_dir = 0;
 	int passthrough = 0;
 	int debug_level = 0;
+	__u32 reset = 0;
 	int new_debug_level, gdebug_level;
 	double timestamp;
 	char ptsstr[64];
@@ -356,9 +365,8 @@ int main(int argc, char **argv)
 
 		options[(int)ch] = 1;
 		switch (ch) {
-                case 0:
-                    if (option_setYuvMode == 1)
-                    {
+                case OptSetYuvMode:
+		    {
 			subs = optarg;
 			while (*subs != '\0') {
 				switch (getsubopt(&subs, subopts, &value)) {
@@ -375,11 +383,10 @@ int main(int argc, char **argv)
 						fprintf(stderr, "invalid yuv mode\n");
 						return 1;
 					}
-					set_yuvMode |= YUVMode;
 					break;
                                 }
                         }
-                    }
+		    }
                     break;
 		case OptHelp:
 			usage();
@@ -424,6 +431,9 @@ int main(int argc, char **argv)
 				}
 			}
 			break;
+		case OptReset:
+			reset = strtol(optarg, 0L, 0);
+			break;
 		case OptPassThrough:
 			passthrough = strtol(optarg, 0L, 0);
 			break;
@@ -585,17 +595,15 @@ int main(int argc, char **argv)
 		doioctl(fd, VIDEO_SELECT_SOURCE, (void *)(unsigned long)(passthrough ? VIDEO_SOURCE_DEMUX : VIDEO_SOURCE_MEMORY), "IVTV_IOC_PASSTHROUGH");
 	}
 
-	if (option_reset_ir) {
-		__u32 dummy = 0;
-
-		doioctl(fd, VIDIOC_INT_RESET, &dummy, "VIDIOC_INT_RESET");
+	if (options[OptReset]) {
+		doioctl(fd, VIDIOC_INT_RESET, &reset, "VIDIOC_INT_RESET");
 	}
 
-	if (option_version) {
+	if (options[OptVersion]) {
                 printf("ivtvctl version " IVTV_VERSION "\n");
 	}
 
-        if (option_setYuvMode)
+        if (options[OptSetYuvMode])
         {
 		struct ivtv_dma_frame frame;
 		struct v4l2_format fmt;
@@ -608,6 +616,7 @@ int main(int argc, char **argv)
 
 		printf("set yuv mode\n");
 		memset(&frame, 0, sizeof(frame));
+		frame.type = V4L2_BUF_TYPE_VIDEO_OUTPUT;
 		if (ioctl(fd, IVTV_IOC_DMA_FRAME, &frame) < 0) {
 			fprintf(stderr, "Unable to switch to user DMA YUV mode\n");
 			exit(1);
@@ -618,12 +627,13 @@ int main(int argc, char **argv)
 		doioctl(fd, VIDIOC_S_FMT, &fmt, "VIDIOC_S_FMT");
         }
 
-        if (option_getYuvMode)
+        if (options[OptGetYuvMode])
         {
 		struct ivtv_dma_frame frame;
 		struct v4l2_format fmt;
 		
 		memset(&frame, 0, sizeof(frame));
+		frame.type = V4L2_BUF_TYPE_VIDEO_OUTPUT;
 		if (ioctl(fd, IVTV_IOC_DMA_FRAME, &frame) < 0) {
 			fprintf(stderr, "Unable to switch to user DMA YUV mode\n");
 			exit(1);
